<?php
namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;

class Event
{

    const QUEST = 1;

    const TOURNAMENT = 2;

    const FREE_BATTLE = 3;

    const LEAGUE_MATCHDAY = 4;

    // Reserved value (was "wanted" battles)
    const CLAN_BATTLE = 6;

    private ?int $id;

    private int $type = self::QUEST;

    private int $version = 1;

    private Collection $heroes;

    private Collection $battles;

    public function __construct()
    {
        $this->heroes = new ArrayCollection();
        $this->battles = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getType(): ?int
    {
        return $this->type;
    }

    public function setType(int $type): self
    {
        $this->type = $type;

        return $this;
    }

    /**
     * @return Collection|EventHero[]
     */
    public function getHeroes(): Collection
    {
        return $this->heroes;
    }

    public function addHero(EventHero $hero): self
    {
        if (!$this->heroes->contains($hero)) {
            $this->heroes[] = $hero;
            $hero->setEvent($this);
        }

        return $this;
    }

    public function removeHero(EventHero $hero): self
    {
        if ($this->heroes->contains($hero)) {
            $this->heroes->removeElement($hero);
            // set the owning side to null (unless already changed)
            if ($hero->getEvent() === $this) {
                $hero->setEvent(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|EventBattle[]
     */
    public function getBattles(): Collection
    {
        return $this->battles;
    }

    public function addBattle(EventBattle $battle): self
    {
        if (!$this->battles->contains($battle)) {
            $this->battles[] = $battle;
            $battle->setEvent($this);
        }

        return $this;
    }

    public function removeBattle(EventBattle $battle): self
    {
        if ($this->battles->contains($battle)) {
            $this->battles->removeElement($battle);
            // set the owning side to null (unless already changed)
            if ($battle->getEvent() === $this) {
                $battle->setEvent(null);
            }
        }

        return $this;
    }

    public function getVersion(): ?int
    {
        return $this->version;
    }

    public function setVersion(int $version): self
    {
        $this->version = $version;

        return $this;
    }
}

